<?php
/*************************************************************************************/
/*      This file is part of the Thelia package.                                     */
/*                                                                                   */
/*      Copyright (c) OpenStudio                                                     */
/*      email : dev@thelia.net                                                       */
/*      web : http://www.thelia.net                                                  */
/*                                                                                   */
/*      For the full copyright and license information, please view the LICENSE.txt  */
/*      file that was distributed with this source code.                             */
/*************************************************************************************/

namespace EkomiIntegration\Controller;
use Symfony\Component\HttpFoundation\JsonResponse;
use Thelia\Controller\Admin\BaseAdminController;
use Thelia\Core\Security\AccessManager;
use Thelia\Core\Security\Resource\AdminResources;
use Thelia\Log\Tlog;
use Thelia\Model\ConfigQuery;


/**
 * Class Configuration
 * @package EkomiIntegration\Controller
 * @author eKomi
 */
class Configuration extends BaseAdminController {

    public function saveAction()
    {
        if (null !== $response = $this->checkAuth(array(AdminResources::MODULE), array('ekomiintegration'), AccessManager::UPDATE)) {
            return $response;
        }

        $form = new \EkomiIntegration\Form\Configuration($this->getRequest());
        $resp = array(
            "error" =>  0,
            "message" => ""
        );
        $response = null;
        $ApiUrl   = 'http://api.ekomi.de/v3/getSettings';

        try {
            $vform = $this->validateForm($form);
            $data = $vform->getData();
            $shopId = $data['shopid'];
            $shopPw = $data['secret'];
            if(!empty($shopId) && !empty($shopPw)) {
                $ch = curl_init();
                curl_setopt($ch, CURLOPT_URL, $ApiUrl . "?auth=" . $shopId . "|" . $shopPw . "&version=cust-1.0.0&type=request&charset=iso&app=PD-Thelia");
                curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
                $server_output = curl_exec($ch);
                curl_close($ch);
                if ($server_output == 'Access denied' || $server_output == 'NonVersion') {
                    $resp["error"] = 1;
                    $resp["message"] ="Access denied , Incorrect shop id or secret";
                } else {
                    //var_dump($data);
                    foreach ($data as $name => $value) {
                        if (! $form->isTemplateDefinedHiddenFieldName($name)) {
                            ConfigQuery::write("ekomiintegration_" . $name, $value, false, true);
                        }
                        Tlog::getInstance()->debug(sprintf("%s => %s", $name, $value));
                    }
                }
            } else {
                $resp["error"] = 1;
                $resp["message"] = "Shop ID and Secret are required";
                $message['success'] = false;
            }
        } catch (\Exception $e) {
            $resp["error"] = 1;
            $resp["message"] = $e->getMessage();
        }
        return JsonResponse::create($resp);
    }
} 