<?php
/*************************************************************************************/
/*      This file is part of the Thelia package.                                     */
/*                                                                                   */
/*      Copyright (c) OpenStudio                                                     */
/*      email : dev@thelia.net                                                       */
/*      web : http://www.thelia.net                                                  */
/*                                                                                   */
/*      For the full copyright and license information, please view the LICENSE.txt  */
/*      file that was distributed with this source code.                             */
/*************************************************************************************/

namespace EkomiIntegration\Form;

use Thelia\Core\Translation\Translator;
use Thelia\Form\BaseForm;
use Thelia\Model\ConfigQuery;

/**
 * Class Configuration
 * @package EkomiIntegration\Form
 * @author eKomi
 */
class Configuration extends BaseForm {

    protected function buildForm()
    {
        $form = $this->formBuilder;

        $mode = ConfigQuery::read("ekomiintegration_mode", "");
        $shopId = ConfigQuery::read("ekomiintegration_shopid", "");
        $shopSecret = ConfigQuery::read("ekomiintegration_secret", "");
        $productRev = ConfigQuery::read("ekomiintegration_reviews", "");
        $statuses = ConfigQuery::read("ekomiintegration_statuses", "");
        $termsAndConditions = ConfigQuery::read("ekomiintegration_termsAndConditions", 1);

        if(!is_numeric($productRev)){
            $productRev = 0;
        }
        if(!is_numeric($statuses)){
            $statuses = 4;
        }

        $form->add(
            "mode",
            "number",
            array(
                'data'  => (empty($mode)) ? 1 : $mode,
                'label' => Translator::getInstance()->trans("Mode"),
                'label_attr' => array(
                    'for' => "mode"
                ),
            )
        );
        $form->add(
            "shopid",
            "text",
            array(
                'data'  => $shopId,
                'label' => Translator::getInstance()->trans("Shop ID"),
                'label_attr' => array(
                    'for' => "shopid"
                ),
            )
        );
        $form->add(
            "secret",
            "text",
            array(
                'data'  => $shopSecret,
                'label' => Translator::getInstance()->trans("Shop Secret"),
                'label_attr' => array(
                    'for' => "secret"
                ),
            )
        );
        $form->add(
            "reviews",
            "number",
            array(
                'data'  => (empty($productRev)) ? 0 : $productRev,
                'label' => Translator::getInstance()->trans("Product Reviews"),
                'label_attr' => array(
                    'for' => "reviews"
                ),
            )
        );
        $form->add(
            "statuses",
            "number",
            array(
                'data'  => (empty($statuses)) ? 0 : $statuses,
                'label' => Translator::getInstance()->trans("Order Status"),
                'label_attr' => array(
                    'for' => "statuses"
                ),
            )
        );
        $form->add(
            "termsAndConditions",
            "number",
            array(
                'data'  => $termsAndConditions,
                'label' => Translator::getInstance()->trans("Terms and Conditions"),
                'label_attr' => array(
                    'for' => "termsAndConditions",
                ),
            )
        );
    }

    /**
     * @return string the name of you form. This name must be unique
     */
    public function getName()
    {
        return "ekomiintegration";
    }

} 